package org.apache.bcel.util;

import java.lang.ref.SoftReference;
import java.util.HashMap;
import java.util.Map;
import org.apache.bcel.classfile.JavaClass;

/* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/MemorySensitiveClassPathRepository.class */
public class MemorySensitiveClassPathRepository extends AbstractClassPathRepository {
    private final Map<String, SoftReference<JavaClass>> loadedClasses;

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public /* bridge */ /* synthetic */ JavaClass loadClass(String str) throws ClassNotFoundException {
        return super.loadClass(str);
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public /* bridge */ /* synthetic */ JavaClass loadClass(Class cls) throws ClassNotFoundException {
        return super.loadClass((Class<?>) cls);
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public /* bridge */ /* synthetic */ ClassPath getClassPath() {
        return super.getClassPath();
    }

    public MemorySensitiveClassPathRepository(ClassPath path) {
        super(path);
        this.loadedClasses = new HashMap();
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public void clear() {
        this.loadedClasses.clear();
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public JavaClass findClass(String className) {
        SoftReference<JavaClass> ref = this.loadedClasses.get(className);
        if (ref == null) {
            return null;
        }
        return ref.get();
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public void removeClass(JavaClass clazz) {
        this.loadedClasses.remove(clazz.getClassName());
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public void storeClass(JavaClass clazz) {
        this.loadedClasses.put(clazz.getClassName(), new SoftReference<>(clazz));
        clazz.setRepository(this);
    }
}
